#
# spec file for package steam
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           steam
Version:        1.0.0.66
Release:        lp151.3.3.1
Summary:        Installer for Valve's digital software distribution service
# "Limited Installation License"
License:        SUSE-Freeware
Group:          Amusements/Games/Other
URL:            http://www.steampowered.com/
Source:         http://repo.steampowered.com/steam/pool/steam/s/steam/steam_%{version}.tar.gz
Source2:        steam.appdata.xml
Source3:        %{name}-streaming.xml 
# Based on https://raw.githubusercontent.com/steamtricks/steamtricks/master/dist/patch/steam-invoke_steamtricks.patch
Patch0:         steam-invoke_steamtricks.patch
# PATCH-FIX-OPENSUSE steam-path-fix.patch bnc#1025841
Patch1:         steam-path-fix.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig(shared-mime-info)
BuildRequires:  update-desktop-files
BuildRequires:  fdupes
BuildRequires:  pkgconfig(udev)
BuildRequires:  firewall-macros

# for Steam Hardware Survey
Recommends:     lsb-release

# dep_postfix macro is used to append "-32bit" to dependencies for x86_64 on openSUSE
%define dep_postfix %{nil}
%ifarch x86_64
  %define dep_postfix -32bit
%endif

Requires:       Mesa-libGL1%{dep_postfix}
Requires:       alsa%{dep_postfix} >= 1.0.23
Requires:       alsa-devel%{dep_postfix} >= 1.0.23
Requires:       dbus-1-glib%{dep_postfix}
Requires:       gtk2-engine-oxygen%{dep_postfix}
Requires:       libSDL-1_2-0%{dep_postfix} >= 1.2.10
Requires:       libX11-6%{dep_postfix} >= 1.4.99.1
Requires:       libXdmcp6%{dep_postfix}
Requires:       libXext6%{dep_postfix}
Requires:       libXfixes3%{dep_postfix}
Requires:       libXi6%{dep_postfix} >= 1.2.99.4
Requires:       libXrandr2%{dep_postfix} >= 1.2.99.3
Requires:       libXrender1%{dep_postfix}
Requires:       libatk-1_0-0%{dep_postfix}
Requires:       libcairo2%{dep_postfix} >= 1.6.0
Requires:       libcurl4%{dep_postfix} >= 7.16.2-1
Requires:       libdbus-1-3%{dep_postfix} >= 1.2.14
Requires:       libfreetype6%{dep_postfix} >= 2.3.9
%if 0%{?suse_version} >= 1315
Requires:       libgcrypt20%{dep_postfix} >= 1.6.1
%else
Requires:       libgcrypt11%{dep_postfix} >= 1.4.5
%endif
Requires:       libgdk_pixbuf-2_0-0%{dep_postfix} >= 2.22.0
Requires:       libglib-2_0-0%{dep_postfix} >= 2.14.0
Requires:       libgmodule-2_0-0%{dep_postfix}
Requires:       libgobject-2_0-0%{dep_postfix}
Requires:       libgtk-2_0-0%{dep_postfix} >= 2.24.0
Requires:       libogg0%{dep_postfix} >= 1.0
Requires:       libpango-1_0-0%{dep_postfix} >= 1.22.0
Requires:       libpixman-1-0%{dep_postfix} >= 0.24.4
Requires:       libpng12-0%{dep_postfix} >= 1.2.13
Requires:       libpulse0%{dep_postfix} >= 0.99.1
Requires:       libtheora0%{dep_postfix} >= 1.0
Requires:       libvorbis0%{dep_postfix} >= 1.1.2
Requires:       mozilla-nspr%{dep_postfix} >= 1.8.0.10
Requires:       mozilla-nss%{dep_postfix} >= 3.12.3
%if 0%{?suse_version} < 1330
Requires:       cups-libs%{dep_postfix} >= 1.4.0
%else
Requires:       libcups2%{dep_postfix}
%endif
Requires:       fontconfig%{dep_postfix} >= 2.8.0
Requires:       glibc%{dep_postfix} >= 2.15
Requires:       openal-soft >= 1.13
Requires:       zlib%{dep_postfix} >= 1.2.3.3
Requires:       libgcc_s1%{dep_postfix} >= 4.1.1
Requires:       libopenal1%{dep_postfix} >= 1.13
Requires:       libstdc++6%{dep_postfix} >= 4.6

# our own builds of libcrypto.so.1 and libssl.so.1.
Requires:	libopenssl1_0_0-steam
%ifarch x86_64
Requires:	libopenssl1_0_0-steam-32bit
%endif

# from steamdeps.txt which uses Debian package syntax
Requires:       curl
Requires:       xz
Requires:       zenity
Requires:       libxcb-dri2-0%{dep_postfix}
Requires:       libxcb-glx0%{dep_postfix}
Recommends:     bubblewrap

# replaces steamruntime-fix and is required for steam to boot
Requires:       steamtricks

#Proton Requirements
Requires:		python3
Recommends:		vulkan
Recommends:		libvulkan1-32bit

%description
Steam is a software distribution service with an online store, automated
installation, automatic updates, achievements, SteamCloud synchronized
savegame and screenshot functionality, and many social features.

This package will fetch and install the Steam bootstrap. Start Steam to
complete the installation of the client for the current user.

%package        devices
Summary:        Device support for Steam-related hardware
URL:            https://github.com/ValveSoftware/steam-devices/
License:        MIT
Group:          Hardware/Joystick
Obsoletes:      steam-controller < %{version}
Obsoletes:      steam-vr < %{version}
Provides:       steam-controller = %{version}
Provides:       steam-vr = %{version}
Supplements:    steam = %{version}
Requires:       steam = %{version}
%if 0%{?suse_version} >= 1330
Requires(pre):  group(games)
Requires(pre):  user(games)
%endif

%description devices
The Steam Controller features dual trackpads, HD haptic feedback, dual-stage
triggers, back grip buttons, and fully-customizable control schemes.
Make sure that all users, which should have access to the steam-controller,
are in the "games" group. Steam VR is a full-featured, 360° room-scale 
virtual reality experience.


%prep
%autosetup -n steam-launcher -p1


%build

%install
make DESTDIR=%{buildroot} install-bin install-docs install-icons install-bootstrap install-desktop

# TODO: Patch it so it works with zypper or at least does not invoke apt-get.
rm %{buildroot}%{_bindir}/steamdeps
rm %{buildroot}%{_prefix}/lib/steam/bin_steamdeps.py

mkdir -p %{buildroot}%{_udevrulesdir}
cp subprojects/steam-devices/60-steam-input.rules %{buildroot}%{_udevrulesdir}/60-steam-input.rules
cp subprojects/steam-devices/60-steam-vr.rules %{buildroot}%{_udevrulesdir}/60-steam-vr.rules

# https://en.opensuse.org/openSUSE:AppStore
install -Dm0644 %{SOURCE2} %{buildroot}%{_datadir}/appdata/%{name}.appdata.xml

install -Dm644 %{SOURCE3} %{buildroot}%{_prefix}/lib/firewalld/services/steam-streaming.xml

%fdupes %{buildroot}%{_prefix}

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post
%firewalld_reload

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%post devices
%{?udev_rules_update:%udev_rules_update}

%postun devices
%{?udev_rules_update:%udev_rules_update}

%files
%{_bindir}/%{name}
%dir %{_prefix}/lib/%{name}
%{_prefix}/lib/%{name}/bootstraplinux_ubuntu12_32.tar.xz
%{_datadir}/pixmaps/%{name}_tray_mono.png
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%dir %{_datadir}/doc/%{name}
%doc %{_datadir}/doc/%{name}/steam_subscriber_agreement.txt
%doc %{_datadir}/doc/%{name}/README
%doc debian/changelog
%{_mandir}/man6/%{name}.6%{?ext_man}
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%dir %{_prefix}/lib/firewalld
%dir %{_prefix}/lib/firewalld/services
%{_prefix}/lib/firewalld/services/steam-streaming.xml
%{_prefix}/lib/steam/bin_steam.sh
%{_prefix}/lib/steam/steam.desktop

%files devices
%license subprojects/steam-devices/LICENSE
%{_udevrulesdir}/60-%{name}-input.rules
%{_udevrulesdir}/60-%{name}-vr.rules

%changelog
* Thu Jul 30 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 1.0.0.66
  * Bootstrap using updated Steam client:
  - Client timestamp 1595977781 (2020-07-28)
  - Steam Runtime version 0.20200604.0
  * Update steam-devices subproject up to 2020-07-28
  - Replace escaped double quotes in udev rules with single quotes, for
    compatibility with udev < 235 and eudev.
- Add Recommends: bubblewrap, required by the experimental container
  runtime system
- Switch to FirewallD
* Wed Jun 17 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 1.0.0.63
  * Update steam-devices subproject up to 2020-06-05
  - Add HORIPAD for Nintendo Switch (thanks, @BrokenGale)
    (Fixes: steam-for-linux#6944, steam-devices#7)
  - Add ASTRO C40 controller (thanks, @exhumer2)
    (Fixes: steam-devices#5)
  - Add PowerA Nintendo Switch Controller (thanks, @blazingkin)
    (Fixes: steam-devices#6)
  - Add a workaround for PowerA Wireless Controller
    (thanks, Andrey Smirnov) (Fixes: steam-devices#9; T21767)
  * debian/steam-launcher.postinst: Notify udevd to reload its rules.
    This means the steam-devices rules should take effect immediately,
    instead of being deferred until after the next reboot. (T19535)
  * bin_steam.sh: Don't overwrite steam.desktop if it's a symlink.
    In a pre-configured distro like SteamOS, ~/Desktop/steam.desktop
    might already be a symlink to /usr/share/applications/steam.desktop,
    in which case overwriting it is pointless. (T21633)
- steam-devices supplements steam
- Update to version 1.0.0.64
  * steam.list: Download updates via https (T21740)
    In older versions of apt (lower than 1.6) we need to install
    apt-transport-https to use https repositories, so do that.
  * steam.list: Switch the suite from precise to stable
    (Fixes: steam-for-linux#4436)
  * steam.list: Add commented-out apt sources for the beta launcher
* Fri Jun  5 2020 Matthias Mailänder <mailaender@opensuse.org>
- Added recommend lsb-release to provide OS info and to support
  hw survey boo#1157832
* Sat May 23 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update patches for new package structure
- Merge steam-controller and steam-vr into steam-devices like other distros.
- Update to version 1.0.0.62
  * Adapt for newer Steam Runtime builds
* Mon Dec 30 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Drop libnm-glib4 and libnm-util2 dependencies: steam appears to
  run just fine without those libs nowadays (boo#1157903).
* Thu Oct  3 2019 Yunhe Guo <i@guoyunhe.me>
- Remove unnecessary desktop file modification
  * Original is good: Categories=Network;FileTransfer;Game;
  * Modified, Categories=Game;Amusement;, will list steam in Games >
    Toys category in KDE, which doesn't fit a game store.
* Wed Jun 12 2019 Jon Brightwell <jon@moozaad.co.uk>
- update to version 1.0.0.61
  * Update udev rules
- includes version 1.0.0.60
  * Updates to the bootstraping logic and bootstraping runtime
- Added steam-path-fix.patch to correct lspci not found
* Mon Mar 25 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add recommended 32bit vulkan library
* Thu Dec 20 2018 mailaender@opensuse.org
- update to version 1.0.0.59
  * Update udev rules.
  * Add --run option to the steam command, will exec a command
    through run.sh in the steam runtime environment.
* Sat Sep 29 2018 Avindra Goolcharan <avindra@opensuse.org>
- update to version 1.0.0.56
  * Rename udev rules files to 60-* to fix permissions to /dev/uinput
    for the currently logged in user.
- includes version 1.0.0.55
  * Update locstrings for .desktop file
  * Update udev rules for VR and controllers
- drop allow-non-root-controller-access.patch (fixed upstream)
- partial cleanup with spec-cleaner
* Sun Aug 26 2018 jon@moozaad.co.uk
- Added proton requirements (python3) and recommended vulkan
* Tue Nov 14 2017 christophe@krop.fr
- Require libcups2-32bit if the package is available. (boo#1067133)
* Sat Aug  5 2017 mailaender@opensuse.org
- Require "games" group and user (boo#1043738)
* Sat Mar 11 2017 robert.munteanu@gmail.com
- Add firewall file to allow easier access to in-home streaming
* Wed Dec 21 2016 jimmy@boombatower.com
- Replace steamruntime-fix with steamtricks.
  invoke-libstdc-removal-before-starting-steam.patch
  steam-invoke_steamtricks.patch
* Tue Dec 13 2016 develop7@develop7.info
- update to version 1.0.0.54
- refreshed allow-non-root-controller-access.patch
* Sat Nov 19 2016 mailaender@opensuse.org
- update to version 1.0.0.53
  * Update udev rules for HTC Vive and order them so they run after
  50-udev-default.rules but before 73-seat-late.rules
- Add appdata.xml for https://software.opensuse.org/appstore
* Sat Oct  1 2016 jimmy@boombatower.com
- Surround all home directory usages with quotes.
* Wed Sep 28 2016 jimmy@boombatower.com
- Search and remove libstdc from steam library directories as well
  to ensure apps shipping their own incompatible versions work.
* Mon Sep 26 2016 jimmy@boombatower.com
- correct replacement of 64bit openssl libraries in steamruntime.
* Mon Sep 12 2016 meissner@suse.com
- require our own builds of the openssl libraries
  and replace them on runtime. bsc#988273
* Mon Aug 15 2016 rpm@fthiessen.de
- Added allow-non-root-controller-access.patch for fixing
  boo#986901
- Droped special handling of openSUSE <= 12.3 as it is not
  maintained anymore.
* Sun Jul 10 2016 jimmy@boombatower.com
- Add invoke-libstdc-removal-before-starting-steam.patch to resolve
  long standing issue:
  https://github.com/ValveSoftware/steam-for-linux/issues/3273
* Mon Jun 13 2016 mailaender@opensuse.org
- update to version 1.0.0.52
- add SteamVR (HTC Vive) support
- add (Debian) changelog
* Fri Apr 29 2016 mailaender@opensuse.org
- don't strip the translation from .desktop file (fixes boo#974334)
* Sat Mar  5 2016 mailaender@opensuse.org
- add Steam controller support
* Sat Nov 21 2015 mailaender@opensuse.org
- update to version 1.0.0.51
* Thu Sep 10 2015 ecsos@opensuse.org
- fix build error for openSUSE 13.1 and 13.2
* Wed Sep  9 2015 dimstar@opensuse.org
- on openSUSE Leap 42.1, we have libgcrypt20-32bit.
* Mon Jun 22 2015 robert.munteanu@gmail.com
- Require alsa-devel to fix launching of unity3D games (
    https://github.com/ValveSoftware/steam-for-linux/issues/3888 )
* Wed May 13 2015 mailaender@opensuse.org
- update to version 1.0.0.50
  * Added libXinerama and libXext to the bootstrap runtime to fix AMD
    graphics driver crashing if these aren't present.
* Mon Dec 29 2014 mailaender@opensuse.org
- remove Fedora exceptions as they got their own RPM
- rework this from fetch script to a real package
- adhere to en.opensuse.org/SourceUrls
- adhere to en.opensuse.org/openSUSE:Packaging_desktop_menu_categories
- clean the package from duplicate icon files
* Sat Oct  4 2014 mailaender@opensuse.org
- update to 1.0.0.49
  * Update packaged icons.
  * Update liblibstdc++ file version to match new runtime.
* Tue Jul  8 2014 speilicke@suse.com
- Require libgcrypt20 on 13.20 or newer, libgcrypt11 was dropped there
* Fri Jun 20 2014 romulasry@gmail.com
- update to 1.0.0.48
* Wed May 28 2014 martadinata666@gmail.com
- update to 1.0.0.47
* Thu Dec 26 2013 mailaender@opensuse.org
- Don't spam the subscriber agreement in the RPM console as Steam
  itself will display a proper EULA in a GUI to accept on first
  start when it downloads the real runtime and client.
- Update instructions of the RPM file description.
- Added missing desktop, icon, mime database update macros.
* Thu Dec  5 2013 mailaender@opensuse.org
- update to 1.0.0.45
- explicit file attributes required in spec to fix build in 12.2
* Sun Dec  1 2013 mihai.petracovici@gmail.com
- Spec file clean-up
  * Package now properly uninstalls
* Sat Nov 23 2013 mailaender@opensuse.org
- update to 1.0.0.44
* Sat Oct 12 2013 mailaender@opensuse.org
- update to 1.0.0.43
* Mon Sep 16 2013 bwiedemann@suse.com
- require dbus-1-glib-32bit libnm-glib4-32bit libnm-util2-32bit
* Mon Sep  9 2013 mailaender@opensuse.org
- update to 1.0.0.41
* Sun Jul  7 2013 mailaender@opensuse.org
- update to 1.0.0.39
* Wed Mar 13 2013 mailaender@opensuse.org
- update to 1.0.0.36
- display EULA before installation
* Tue Mar 12 2013 mailaender@opensuse.org
- fix openal dependency for openSUSE 12.3 (bnc#808951)
* Wed Mar  6 2013 mailaender@opensuse.org
- update to 1.0.0.35
- fix problems with 32bit dependencies on x64 (bnc#806576)
* Sun Feb 24 2013 mailaender@opensuse.org
- update to 1.0.0.33
- require tar instead of ar since we don't unpack a .deb anymore
- use lynx to dump only the text of the EULA without HTML tags
* Sat Feb 23 2013 buschmann23@opensuse.org
- added make and binutils explicit to the Requirements
* Tue Feb 19 2013 buschmann23@opensuse.org
- added conditional to requirements of gcc libs because names
  changed in openSUSE 12.3
* Sun Feb 17 2013 i@marguerite.su
- add Requires: libXdmcp6-32bit.
* Sat Feb 16 2013 mailaender@opensuse.org
- update to 1.0.0.28
* Sun Feb 10 2013 mailaender@opensuse.org
- updated to 1.0.0.25
- use the new tar.gz provided by Valve
* Fri Feb  1 2013 mailaender@opensuse.org
- updated to 1.0.0.22
- created fetch-steam.sh to circumvent the "Limited Installation License"
- removed all non-free binaries and scripts distributed by Valve
* Fri Dec 21 2012 prusnak@opensuse.org
- updated to 1.0.0.18
* Thu Dec 20 2012 prusnak@opensuse.org
- spec cleanup
* Sat Dec  8 2012 jdmulloy@gmail.com
- Added support for x86_64 packages
- Fixed libpng dependency for openSUSE
- Added libopenal1-soft and Mesa-libGL1 dependencices for openSUSE
* Tue Nov 20 2012 mailaender@opensuse.org
- SUSE specific fixes
* Wed Nov  7 2012 spot@fedoraproject.org
- add more Requires (from downloaded bits, not packaged bits)
* Tue Nov  6 2012 spot@fedoraproject.org
- fedora specific libpng conditionalization
* Tue Nov  6 2012 spot@fedoraproject.org
- initial Fedora RPM packaging
